==> google_cloud_beyondcorp_appconnections-0.1.1-py2.py3-none-any.whl: google/cloud/beyondcorp_appconnections_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.app_connections_service import AppConnectionsServiceClient
from .services.app_connections_service import AppConnectionsServiceAsyncClient

from .types.app_connections_service import AppConnection
from .types.app_connections_service import AppConnectionOperationMetadata
from .types.app_connections_service import CreateAppConnectionRequest
from .types.app_connections_service import DeleteAppConnectionRequest
from .types.app_connections_service import GetAppConnectionRequest
from .types.app_connections_service import ListAppConnectionsRequest
from .types.app_connections_service import ListAppConnectionsResponse
from .types.app_connections_service import ResolveAppConnectionsRequest
from .types.app_connections_service import ResolveAppConnectionsResponse
from .types.app_connections_service import UpdateAppConnectionRequest

__all__ = (
    "AppConnectionsServiceAsyncClient",
    "AppConnection",
    "AppConnectionOperationMetadata",
    "AppConnectionsServiceClient",
    "CreateAppConnectionRequest",
    "DeleteAppConnectionRequest",
    "GetAppConnectionRequest",
    "ListAppConnectionsRequest",
    "ListAppConnectionsResponse",
    "ResolveAppConnectionsRequest",
    "ResolveAppConnectionsResponse",
    "UpdateAppConnectionRequest",
)

==> google_cloud_beyondcorp_appconnections-0.4.14-py2.py3-none-any.whl: google/cloud/beyondcorp_appconnections_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.beyondcorp_appconnections_v1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.app_connections_service import (
    AppConnectionsServiceAsyncClient,
    AppConnectionsServiceClient,
)
from .types.app_connections_service import (
    AppConnection,
    AppConnectionOperationMetadata,
    CreateAppConnectionRequest,
    DeleteAppConnectionRequest,
    GetAppConnectionRequest,
    ListAppConnectionsRequest,
    ListAppConnectionsResponse,
    ResolveAppConnectionsRequest,
    ResolveAppConnectionsResponse,
    UpdateAppConnectionRequest,
)

__all__ = (
    "AppConnectionsServiceAsyncClient",
    "AppConnection",
    "AppConnectionOperationMetadata",
    "AppConnectionsServiceClient",
    "CreateAppConnectionRequest",
    "DeleteAppConnectionRequest",
    "GetAppConnectionRequest",
    "ListAppConnectionsRequest",
    "ListAppConnectionsResponse",
    "ResolveAppConnectionsRequest",
    "ResolveAppConnectionsResponse",
    "UpdateAppConnectionRequest",
)
